@@ -182,7 +182,7 @@ abstract class AbstractConnection extends AbstractChannel
         $login_method = 'AMQPLAIN',
         $login_response = null,
         $locale = 'en_US',
-        AbstractIO $io = null,
+        ?AbstractIO $io = null,
         $heartbeat = 0,
         $connection_timeout = 0,
         $channel_rpc_timeout = 0.0,
@@ -424,6 +424,7 @@ abstract class AbstractConnection extends AbstractChannel
         $this->frame_queue = new \SplQueue();
         $this->method_queue = [];
         $this->setIsConnected(false);
+        $this->closeChannelsIfDisconnected();
         $this->close_input();
         $this->close_socket();
     }
@@ -718,7 +719,7 @@ abstract class AbstractConnection extends AbstractChannel
         if (!$this->is_connected) {
             $this->connect();
         }
-        if (isset($this->channels[$channel_id])) {
+        if ($channel_id !== null && isset($this->channels[$channel_id])) {
             return $this->channels[$channel_id];
         }
 
@@ -1112,6 +1113,21 @@ abstract class AbstractConnection extends AbstractChannel
         }
     }
 
+    /**
+     * Closes all available channels if disconnected
+     */
+    protected function closeChannelsIfDisconnected()
+    {
+        foreach ($this->channels as $key => $channel) {
+            // channels[0] is this connection object, so don't close it yet
+            if ($key === 0) {
+                continue;
+            }
+
+            $channel->closeIfDisconnected();
+        }
+    }
+
     /**
      * Should the connection be attempted during construction?
      *
