@@ -4,7 +4,8 @@ use PhpAmqpLib\Connection\AMQPConnection;
 use PhpAmqpLib\Connection\AMQPStreamConnection;
 use PhpAmqpLib\Message\AMQPMessage;
 
-require_once __DIR__ . '/config.php';
+require __DIR__ . '/../vendor/autoload.php';
+require __DIR__ . '/../tests/config.php';
 
 $conn = new AMQPStreamConnection(HOST, PORT, USER, PASS, VHOST);
 
