@@ -3,7 +3,7 @@
 namespace PhpAmqpLib\Tests\Unit\Wire;
 
 use PhpAmqpLib\Wire;
-use PhpAmqpLib\Wire\AMQPReader;
+use PhpAmqpLib\Wire\AMQPBufferReader;
 use PhpAmqpLib\Tests\TestCaseCompat;
 use PhpAmqpLib\Wire\AMQPAbstractCollection;
 
@@ -27,7 +27,7 @@ class AMQPReaderTest extends TestCaseCompat
             'snowman' => ['x', "\x26\x03"]
         ];
         $data = hex2bin('0000000f07736e6f776d616e78000000022603');
-        $reader = new AMQPReader($data);
+        $reader = new AMQPBufferReader($data);
         $parsed = $reader->read_table();
         $this->assertEquals($expected, $parsed);
     }
@@ -35,7 +35,7 @@ class AMQPReaderTest extends TestCaseCompat
     public function test32bitSignedIntegerOverflow()
     {
         $data = hex2bin('0000000080000000');
-        $reader = new AMQPReader($data);
+        $reader = new AMQPBufferReader($data);
         $parsed = $reader->read_signed_longlong();
         if (PHP_INT_SIZE === 8) {
             $this->assertIsInt($parsed);
@@ -49,7 +49,7 @@ class AMQPReaderTest extends TestCaseCompat
     public function test64bitUnsignedIntegerOverflow()
     {
         $data = hex2bin(str_repeat('f', 16));
-        $reader = new AMQPReader($data);
+        $reader = new AMQPBufferReader($data);
         $parsed = $reader->read_longlong();
         $this->assertIsString($parsed);
         $this->assertEquals('18446744073709551615', $parsed);
@@ -58,13 +58,13 @@ class AMQPReaderTest extends TestCaseCompat
     public function testDecodeFloatingPointValues()
     {
         $data = hex2bin('3a83126f');
-        $reader = new AMQPReader($data);
+        $reader = new AMQPBufferReader($data);
         $parsed = $reader->read_value(AMQPAbstractCollection::T_FLOAT);
         self::assertIsFloat($parsed);
-        self::assertEquals(0.001, $parsed);
+        self::assertEquals(0.0010000000474974513, $parsed);
 
         $data = hex2bin('3feff7ced916872b');
-        $reader = new AMQPReader($data);
+        $reader = new AMQPBufferReader($data);
         $parsed = $reader->read_value(AMQPAbstractCollection::T_DOUBLE);
         self::assertIsFloat($parsed);
         self::assertEquals(0.999, $parsed);
