@@ -49,4 +49,15 @@ class StreamIOTest extends TestCase
 
         $stream->select(0, 0);
     }
+
+    /**
+     * @test
+     */
+    public function connect_ipv6()
+    {
+        $streamIO = new StreamIO(HOST6, PORT, 0.1, 0.1, null, false, 0);
+        $streamIO->connect();
+        $ready = $streamIO->select(0, 0);
+        $this->assertEquals(0, $ready);
+    }
 }
